@@ -6,8 +6,8 @@ from typing import Optional
 from numpy import absolute
 
 from osaft import log
+from osaft.core.fluids import InviscidFluid
 from osaft.core.functions import exp
-from osaft.core.generic_types import t_fluid
 from osaft.core.variable import (
     ActiveListVariable,
     ActiveVariable,
@@ -55,7 +55,7 @@ class BackgroundField:
     """
 
     def __init__(
-        self, fluid: t_fluid,
+        self, fluid: InviscidFluid,
         p_0: float,
         wave_type: WaveType = WaveType.STANDING,
         position: Optional[float] = None,
