@@ -1,4 +1,7 @@
-from typing import Optional
+import collections
+from collections.abc import Callable, Sequence
+from numbers import Number
+from typing import Optional, Union
 
 import matplotlib.pyplot as plt
 import numpy as np
@@ -74,7 +77,7 @@ class ARFPlot:
         """Add solution to list of solutions for plotting
 
         :param solutions: one or multiple solutions,
-        e.g. :class:`osaft.king1934.ARF()`
+            e.g. :class:`osaft.king1934.ARF()`
         """
         if len(solutions) == 0:
             out = 'is_computed_by() takes at least one positional argument '
@@ -94,7 +97,7 @@ class ARFPlot:
         """Remove solution of list of solutions for plotting
 
         :param solution: specific ARF solution, e.g.
-        :class:`osaft.king1932.ARF()`
+            :class:`osaft.king1932.ARF()`
         """
         self._solutions.pop(solution.name, None)
 
@@ -117,17 +120,38 @@ class ARFPlot:
                 all_max = current_max
         return all_max
 
-    def _normalize_arf(self, normalization_name: str) -> None:
-        if normalization_name is None:
-            return None
-        elif normalization_name == 'max':
+    def _normalize_arf(
+        self, normalization: Union[
+            str, Number,
+            Sequence, Callable,
+        ],
+    ) -> None:
+        if normalization is None:
+            return
+        elif isinstance(normalization, str) and normalization == 'max':
             norm = self._find_max()
-        elif normalization_name in self._solutions.keys():
-            norm = self._solutions[normalization_name].arf
-        else:  # pragma: no cover
+        elif (
+            isinstance(normalization, str) and normalization in
+            self._solutions.keys()
+        ):
+            norm = self._solutions[normalization].arf
+        elif isinstance(normalization, Number):
+            norm = normalization
+        elif (
+            (
+                isinstance(normalization, collections.abc.Sequence)
+                or isinstance(normalization, np.ndarray)
+            )
+            and not isinstance(normalization, str)
+        ):
+            norm = normalization
+        elif callable(normalization):
+            norm = [normalization(value) for value in self.x_values]
+        else:
             raise ValueError(
-                'normalization name needs to be either the name '
-                'of a solution or \'max\'',
+                'Invalid normalization:'
+                "Options: None, 'max', name of a solution, a number, "
+                'an array of numbers, or a callable. See documentation.',
             )
         for _, items in self._solutions.items():
             items.normalize_arf(norm)
@@ -135,32 +159,46 @@ class ARFPlot:
     def plot_solutions(
             self,
             ax: Optional[plt.Axes] = None,
-            normalization_name: Optional[str] = None,
+            display_values: Optional[Sequence] = None,
+            normalization: Union[
+                None, str, float,
+                Callable[[float], float],
+            ] = None,
             plot_method=plt.plot,
             **kwargs,
     ) -> (plt.Figure, plt.Axes):
         """Plot all solutions in stack over attribute set via
-        :meth:`set_abscissa()`. If :attr:`normalization_name` is passed,
-        the solution is normalized. If :attr:`normalization_name` is the name
-        of an added solution then the plot is normalized w.r.t. this solution.
-        If :attr:`normalization_name`` = 'max'`, then the plot is normalized
-        w.r.t. to the max value.
+        :meth:`set_abscissa()` or over  ``x_values`` if passed using the
+        plotting methods ``plot_method``.
+        The plot can be normalized if one of the following is passed
+        as ``normalization``:
+
+           - the name of an added solution:
+           - ``'max'``: normalization w.r.t. max value of the ARF in the plot
+           - a ``float``: normalization w.r.t. to a number
+           - a ``callable`` normalization w.r.t. to function that takes the
+             values on the x-axis as an input
 
         :param ax: axes object where plot will be generated
-        :param normalization_name: name of the solutions used for normalizing
+        :param display_values: changing the values for the x-axis
+        :param normalization: normalization (see above)
         :param plot_method: matplotlib native plotting method (e.g.plt.loglog)
         :param kwargs: keyword arguments that get piped to :attr:`plot_method`
         """
 
+        # Compute Values
         self._compute_arf()
-        self._normalize_arf(normalization_name)
+        self._normalize_arf(normalization)
 
+        # Plot
+        if display_values is None:
+            display_values = self.x_values
         for _, data in self._solutions.items():
             fig, ax = self.plotter.plot_solution(
-                self.x_values, data, ax, plot_method, **kwargs,
+                display_values, data, ax, plot_method, **kwargs,
             )
 
-        self.plotter.set_labels(ax, self.attr_name, normalization_name)
+        self.plotter.set_labels(ax, self.attr_name, normalization)
         self.plotter.add_legend(ax)
 
         return fig, ax
