@@ -7,7 +7,7 @@ class BaseARF(ABC):
     """
 
     @abstractmethod
-    def acoustic_radiation_force(self) -> float:
+    def compute_arf(self) -> float:
         """ Returns the value for the ARF in Newton [N].
         This method must be implemented by every theory to have a common
         interface for other modules.
