@@ -33,8 +33,8 @@ class ARF(ScatteringField, BaseARF):
        checked at runtime.
 
 
-    :param frequency: Frequency [Hz]
-    :param radius: Radius of the solid [m]
+    :param f: Frequency [Hz]
+    :param R_0: Radius of the solid [m]
     :param rho_s: Density of the fluid-like solid [kg/m^3]
     :param c_s: Speed of sound of the solid [m/s]
     :param eta_s: shear viscosity of the solid [Pa s]
@@ -53,8 +53,8 @@ class ARF(ScatteringField, BaseARF):
     """
 
     def __init__(
-        self, frequency: Union[Frequency, float, int],
-        radius: Union[Sphere, float, int],
+        self, f: Union[Frequency, float, int],
+        R_0: Union[Sphere, float, int],
         rho_s: float, c_s: float,
         eta_s: float, zeta_s: float,
         rho_f: float, c_f: float,
@@ -72,7 +72,7 @@ class ARF(ScatteringField, BaseARF):
 
         # init of parent class
         super().__init__(
-            frequency=frequency, radius=radius,
+            f=f, R_0=R_0,
             rho_s=rho_s, c_s=c_s, eta_s=eta_s, zeta_s=zeta_s,
             rho_f=rho_f, c_f=c_f, eta_f=eta_f, zeta_f=zeta_f,
             p_0=p_0, wave_type=wave_type, position=position, N_max=N_max,
@@ -166,7 +166,7 @@ class ARF(ScatteringField, BaseARF):
 
     def __repr__(self):
         return (
-            f'Donikov1994Rigid.ARF(frequency={self.f}, radius={self.R_0}, '
+            f'Donikov1994Rigid.ARF(f={self.f}, R_0={self.R_0}, '
             f'rho_s={self.rho_s}, c_s={self.c_s}, '
             f'eta_s={self.eta_s}, zeta_s={self.zeta_s}, '
             f'rho_f={self.rho_f}, c_f={self.c_f}, '
