@@ -30,8 +30,8 @@ class ARF(ScatteringField, BaseARF):
        checked at runtime.
 
 
-    :param frequency: Frequency [Hz]
-    :param radius: Radius of the sphere [m]
+    :param f: Frequency [Hz]
+    :param R_0: Radius of the sphere [m]
     :param rho_s: Density of the fluid-like sphere [kg/m^3]
     :param rho_f: Density of the fluid [kg/m^3]
     :param c_f: Speed of sound of the fluid [m/s]
@@ -48,8 +48,8 @@ class ARF(ScatteringField, BaseARF):
     """
 
     def __init__(
-        self, frequency: Union[Frequency, float, int],
-        radius: Union[Sphere, float, int],
+        self, f: Union[Frequency, float, int],
+        R_0: Union[Sphere, float, int],
         rho_s: float,
         rho_f: float, c_f: float,
         eta_f: float, zeta_f: float,
@@ -67,7 +67,7 @@ class ARF(ScatteringField, BaseARF):
 
         # init of parent class
         super().__init__(
-            frequency=frequency, radius=radius, rho_s=rho_s,
+            f=f, R_0=R_0, rho_s=rho_s,
             rho_f=rho_f, c_f=c_f, eta_f=eta_f, zeta_f=zeta_f,
             p_0=p_0, wave_type=wave_type, position=position, N_max=N_max,
         )
@@ -144,7 +144,7 @@ class ARF(ScatteringField, BaseARF):
 
     def __repr__(self):
         return (
-            f'Donikov1994Rigid.ARF(frequency={self.f}, radius={self.R_0}, '
+            f'Donikov1994Rigid.ARF(f={self.f}, R_0={self.R_0}, '
             f'rho_s={self.rho_s}, rho_f={self.rho_f}, c_f={self.c_f}, '
             f'eta_f={self.eta_f}, zeta_f={self.zeta_f}, '
             f'p_0={self.p_0}, position={self.position}, {self.wave_type}, '
@@ -171,6 +171,11 @@ class ARF(ScatteringField, BaseARF):
             'small_viscous_boundary_layer',
             self.small_viscous_boundary_layer, None,
         )
+        out += SF.get_str_text(
+            'Large delta',
+            'large_viscous_boundary_layer',
+            self.large_viscous_boundary_layer, None,
+        )
         out += SF.get_str_text(
             'Fastened Sphere',
             'fastened_sphere',
