@@ -16,8 +16,8 @@ from osaft.solutions.yosioka1955.base import BaseYosioka
 class ScatteringField(BaseYosioka, BaseScattering):
     """Scattering field class for Yosioka & Kawasima (1955)
 
-    :param frequency: Frequency [Hz]
-    :param radius: Radius of the sphere [m]
+    :param f: Frequency [Hz]
+    :param R_0: Radius of the sphere [m]
     :param rho_s: Density of the fluid-like sphere [kg/m^3]
     :param c_s: Speed of sound of the particle [m/s]
     :param rho_f: Density of the fluid [kg/m^3]
@@ -29,8 +29,8 @@ class ScatteringField(BaseYosioka, BaseScattering):
     """
 
     def __init__(
-        self, frequency: Union[Frequency, float],
-        radius: Union[Sphere, float],
+        self, f: Union[Frequency, float],
+        R_0: Union[Sphere, float],
         rho_s: float, c_s: float, rho_f: float, c_f: float,
         p_0: float, wave_type: WaveType,
         position: Optional[float] = None,
@@ -39,7 +39,7 @@ class ScatteringField(BaseYosioka, BaseScattering):
         """Constructor method
         """
         BaseYosioka.__init__(
-            self, frequency, radius,
+            self, f, R_0,
             rho_s, c_s, rho_f, c_f,
             p_0, wave_type, position,
         )
@@ -76,7 +76,7 @@ class ScatteringField(BaseYosioka, BaseScattering):
 
     def __repr__(self):
         return (
-            f'{type(self)}(frequency={self.f}, radius={self.R_0}, '
+            f'{type(self)}(f={self.f}, R_0={self.R_0}, '
             f'rho_s={self.rho_s}, rho_f={self.rho_f}, '
             f'c_f={self.c_f}, c_s={self.c_s}'
             f'p_0={self.p_0}, position={self.position}, '
