@@ -455,6 +455,14 @@ class BaseTest(NumericTestCase):
         if hasattr(self, 'cls'):
             if isinstance(self.cls, BaseSolution):
                 self.assertTrue(self.cls.name != '')
+
+    def test_copy(self) -> None:
+        if hasattr(self, 'cls'):
+            if isinstance(self.cls, BaseSolution):
+                tmp = self.cls.copy()
+                self.assertTrue(type(self.cls) == type(tmp))
+                self.assertFalse(self.cls is tmp)
+
     # -------------------------------------------------------------------------
     # Generic test methods for properties and methods
     # -------------------------------------------------------------------------
