@@ -1,6 +1,8 @@
 from abc import abstractmethod
+from enum import auto
 
-from osaft import WaveTypes
+from osaft import WaveType
+from osaft.core.backgroundfields import WrongWaveTypeError
 
 
 class HelperARF:
@@ -12,6 +14,11 @@ class HelperARF:
     def compute_arf(self):
         pass
 
+    def test_wrong_wave_type_error(self):
+        WaveType.WRONGWAVETYPE = auto()
+        self.cls.wave_type = WaveType.WRONGWAVETYPE
+        self.assertRaises(WrongWaveTypeError, self.cls.compute_arf)
+
     def test_arf(self) -> None:
         self.do_testing(
             self.compute_arf, self.cls.compute_arf,
@@ -23,7 +30,7 @@ class HelperARF:
 class HelperStandingARF(HelperARF):
 
     def test_arf(self) -> None:
-        self.wave_type = WaveTypes.STANDING
+        self.wave_type = WaveType.STANDING
         self._wave_type.list_of_values = [self.wave_type]
         HelperARF.test_arf(self)
 
@@ -32,7 +39,7 @@ class HelperTravelingARF(HelperARF):
 
     def test_arf(self) -> None:
 
-        self.wave_type = WaveTypes.TRAVELLING
+        self.wave_type = WaveType.TRAVELLING
         self._wave_type.list_of_values = [self.wave_type]
         HelperARF.test_arf(self)
 
