@@ -20,8 +20,8 @@ class BaseTestScattering(BaseTestPlotting):
         self.N_max = 10
 
         self.yosioka = yosioka1955.ScatteringField(
-            frequency=self.f,
-            radius=self.R_0,
+            f=self.f,
+            R_0=self.R_0,
             rho_s=self.rho_s, c_s=self.c_s,
             rho_f=self.rho_f, c_f=self.c_f,
             p_0=self.p_0,
