@@ -45,6 +45,9 @@ class DummyClass(BaseSolution):
     def func_3(self, n: int, arg1: complex, arg2: complex) -> complex:
         return 1 + arg2 * (-1.0) ** n - arg2
 
+    def input_variables(self) -> list:
+        return []
+
 
 class TestBaseTest(BaseTest):
 
